@@ -1,5 +1,6 @@
 from django.contrib.auth import SESSION_KEY
 from django.conf import settings
+from django.http import HttpResponse
 from errors import WsResponseError, WsInvocationError
 import httplib, json, proxy_server
 
@@ -15,11 +16,11 @@ def invoke_backend_service(method, function_path, json_data=dict(), request=None
                 conn = httplib.HTTPConnection(settings.BACKEND_HOST, settings.BACKEND_PORT)
             else:
                 raise WsInvocationError('No port supplied')
-            
+
         headers = proxy_server.RESTFUL_HEADER
 
         if request is not None:
-            
+
             headers[proxy_server.USER_TOKEN] = request.user.pk
             headers[proxy_server.CLIENT_IP] = request.META.get(proxy_server.HTTP_FROM)
             headers[proxy_server.API_KEY] = settings.SECRET_KEY
@@ -28,28 +29,32 @@ def invoke_backend_service(method, function_path, json_data=dict(), request=None
             conn.request(method, function_path, json.dumps(json_data), headers)
         except:
             raise WsInvocationError('Could not connect to service')
-        
+
         response = conn.getresponse()
         response_data = response.read()
         conn.close()
-        
+
         response_json = json.loads(response_data)
 
         if response.status is 200:
             if public == True and response_token == True:
                 raise WsInvocationError('A web service cannot be public and expect a response token')
-            
+
             elif public == False and response_token == True:
                 if proxy_server.USER_TOKEN not in response_json:
                     raise WsResponseError('Server expected user token in response')
-                
-                if proxy_server.USER_TOKEN in response_json:
-                    if request is not None:
-                        request.session[SESSION_KEY] = response_json[proxy_server.USER_TOKEN]
-                        request.user.pk = response_json[proxy_server.USER_TOKEN]
-                        request.session[proxy_server.EXPIRATION_DATE] = response_json[proxy_server.EXPIRATION_DATE]
-            
+
+                if request is not None:
+                    request.session[SESSION_KEY] = response_json[proxy_server.USER_TOKEN]
+                    request.user.pk = response_json[proxy_server.USER_TOKEN]
+                    request.session[proxy_server.EXPIRATION_DATE] = response_json[proxy_server.EXPIRATION_DATE]
+
             return response_json[proxy_server.RESPONSE]
+        elif response.status is 204:
+            if response_token:
+                raise WsResponseError('Backend server didn\'t respond with a token')
+
+            return None
         else:
             if proxy_server.ERROR in response_json:
                 raise WsResponseError(response_json[proxy_server.ERROR][proxy_server.MESSAGE])
@@ -92,12 +97,17 @@ def invoke_backend_service_as_proxy(method, function_path, json_data=dict(), req
         if response.status is 200:
             if response_token and proxy_server.USER_TOKEN not in response_json:
                 raise WsResponseError('Server expected user token in response')
-            
-            return response_json
+
+            return response
+        elif response.status is 204:
+            if response_token:
+                raise WsResponseError('Backend server didn\'t respond with a token')
+
+            return response
         else:
             if proxy_server.ERROR in response_json:
                 raise WsResponseError(response_json[proxy_server.ERROR][proxy_server.MESSAGE])
             else:
                 raise WsResponseError('Unknown error in backend server')
     else:
-        raise WsInvocationError('No backend host and/or port specified')
\ No newline at end of file
+        raise WsInvocationError('No backend host and/or port specified')
